@@ -98,11 +98,11 @@ switch(rotate,  #The orthogonal cases  for GPArotation + ones developed for psyc
    			rotated <- GPArotation::targetT(loadings)
    			loadings <- rotated$loadings} ,
    			
-   	 bifactor = {rotated <- bifactor(loadings)$loadings},
-   	 TargetT =  {rotated <- TargetT(loadings,...)$loadings},
-   	equamax =  {rotated <- equamax(loadings)$loadings}, 
-   	varimin = {rotated <- varimin(loadings)$loadings},
-   	specialT =  {rotated <- specialT(loadings)$loadings}, 
+   	 bifactor = {loadings <- bifactor(loadings)$loadings},    #corrected 16/06/15 to actually return the appropriate value rather than the unrotated solution
+   	 TargetT =  {loadings <- TargetT(loadings,...)$loadings},  #reported by Matthias Bellmann
+   	equamax =  {loadings <- equamax(loadings)$loadings}, 
+   	varimin = {loadings <- varimin(loadings)$loadings},
+   	specialT =  {loadings <- specialT(loadings)$loadings}, 
    	Promax =   {pro <- Promax(loadings)
      			 loadings <- pro$loadings
      			  Phi <- pro$Phi },
